<?php

if ( ! defined('_PS_VERSION_')) {
    exit;
}

include_once __DIR__.'/classes/setup.php';
include_once __DIR__.'/classes/configuration.php';
include_once __DIR__.'/classes/permissions.php';
include_once __DIR__.'/classes/carriers.php';
include_once __DIR__.'/classes/api.php';
include_once __DIR__.'/classes/api_client.php';
include_once __DIR__.'/classes/api_client_response.php';
include_once __DIR__.'/classes/locations.php';
include_once __DIR__.'/classes/hooks.php';
include_once __DIR__.'/classes/helper.php';

/**
 * Class Multiparcelsshipping_Base
 */
class Multiparcelsshipping_Base extends CarrierModule
{

    public $id_carrier; // needed for getOrderShippingCost

    /** @var \MultiParcels_Shipping_Api $api */
    public $api;

    /** @var \MultiParcels_Shipping_Api_Client $apiClient */
    public $apiClient;

    /** @var \MultiParcels_Shipping_Api_Client_Response $apiClientResponse */
    public $apiClientResponse;

    /** @var \MultiParcels_Shipping_Configuration $configuration */
    public $configuration;

    /** @var \MultiParcels_Shipping_Carriers $carriers */
    public $carriers;

    /** @var \MultiParcels_Shipping_Permissions $permissions */
    public $permissions;

    /** @var \MultiParcels_Shipping_Locations $locations */
    public $locations;

    /** @var \MultiParcels_Shipping_Hooks $hooks */
    public $hooks;

    /** @var \MultiParcels_Shipping_Helper $helper */
    public $helper;

    public $tabs = [
        [
            'name'              => 'MultiParcels',
            'class_name'        => 'AdminMyModuleConfig',
            'visible'           => true,
            'parent_class_name' => 'IMPROVE',
            'icon'              => 'multiparcels',
        ],
    ];

    const HOOKS = [
        'header',
        'footer',
        'backOfficeHeader',
        'actionCarrierUpdate',
        'actionValidateStepComplete',
        'displayAdminOrderContentShip', // removed in 1.7.7 - magic done in setup.php
        'displayAdminOrderTabContent', // added in 1.7.7 - magic done in setup.php
        'displayCarrierExtraContent',
        'displayOrderConfirmation',
        'actionGetExtraMailTemplateVars',
    ];

    /**
     * @param  array  $params
     * @param  float  $shipping_cost
     *
     * @return float
     */
    public function getOrderShippingCost($params, $shipping_cost)
    {
        // if there are no locations - hide the carrier
        $query = sprintf("SELECT * FROM `%s` WHERE `id_carrier` = '%d'",
            _DB_PREFIX_.Multiparcelsshipping::TABLE_CARRIER,
            $this->id_carrier);

        $settings = Db::getInstance()->getRow($query);

        if ($settings == false || $settings['type'] != MultiParcels_Shipping_Carriers::TYPE_TERMINAL) {
            return (float)$shipping_cost;
        }

        $delivery_address         = new Address($params->id_address_delivery);
        $address_delivery_country = new Country($delivery_address->id_country);
        $deliveryCountryCode      = $address_delivery_country->iso_code;

        $hasLocations = $this->locations->checkForFrontend($settings['carrier_code'],
            $deliveryCountryCode);

        if ( ! $hasLocations) {
            return false; // hide the carrier
        }

        return (float)$shipping_cost;
    }

    public function getOrderShippingCostExternal($params)
    {
        return true;
    }

    public function hookDisplayAdminOrderContentShip($params)
    {
        return $this->hooks->adminOrderSelectedPickupLocation($params, true);
    }

    public function hookDisplayAdminOrderTabContent($params)
    {
        return $this->hooks->adminOrderSelectedPickupLocation($params);
    }

    public function hookDisplayOrderConfirmation($params)
    {
        return $this->hooks->displaySelectedLocationInOrderConfirmation($params);
    }

    public function hookActionGetExtraMailTemplateVars($params)
    {
        return $this->hooks->displaySelectedLocationInOrderConfirmationEmail($params);
    }

    public function hookDisplayCarrierExtraContent($carrier)
    {
        return $this->hooks->displayPickupSelectionInCheckout($carrier);
    }

    public function hookActionCarrierUpdate($params)
    {
        $this->hooks->actionCarrierUpdate($params);
    }

    public function log($data)
    {
        file_put_contents(__DIR__.'/debug.txt', json_encode($data).PHP_EOL,
            FILE_APPEND);
    }

}
