<?php

if ( ! defined('_PS_VERSION_')) {
    exit;
}

/**
 * Class MultiParcels_Shipping_Api
 */
class MultiParcels_Shipping_Api
{

    /**
     * @var \Multiparcelsshipping
     */
    private $module;

    /**
     * MultiParcels_Shipping_Api constructor.
     *
     * @param  \Multiparcelsshipping  $module
     */
    public function __construct(Multiparcelsshipping $module)
    {
        $this->module = $module;
    }

    /**
     * @return array
     */
    public function basePermissionData()
    {
        return [
            'domain'           => $url = "http".(($_SERVER['SERVER_PORT'] == 443) ? "s" : "")."://".$_SERVER['HTTP_HOST'],
            'platform'         => 'prestashop',
            'platform_version' => _PS_VERSION_,
            'plugin_version'   => Multiparcelsshipping::VERSION,
        ];
    }

    /**
     * @param  string  $email
     */
    public function requestApiKey($email)
    {
        $data          = $this->basePermissionData();
        $data['email'] = $email;

        $response = $this->module->apiClient->request('restricted_api',
            'POST', $data);

        if ($response->was_successful()) {
            $data = $response->get_data();

            $this->module->configuration->setApiKey($data['api_key']);
        }
    }

    public function updatePermissions()
    {
        $data            = $this->basePermissionData();
        $data['api_key'] = $this->module->configuration->getApiKey();

        $response = $this->module->apiClient->request('restricted_api/permissions',
            'POST', $data);

        if ($response->was_successful()) {
            $data = $response->get_data();

            $this->module->configuration->setPermissions($data['permission']);
        }
    }

    public function updateCarriers()
    {
        $response = $this->module->apiClient->request('restricted_api/couriers');

        $this->module->configuration->setCarriers($response->get_data());
    }

    public function updateLocations()
    {
        $count       = 0;
        $allCarriers = $this->module->configuration->getCarriers();
		 foreach ($allCarriers['carriers'] as $carrier) {
        // Patikriname, ar "carrier_code" nėra "dpd"
        if ($carrier['carrier_code'] !== 'dpd') {
            if ($this->module->configuration->checkCarrier($carrier['carrier_code'])) {
					$carriers[] = $carrier['carrier_code'];
				}
			}
		}
		// Dabar $carriers turi tik tuos ne "dpd" carrierius
		/* var_dump($carriers);
		die(); */

        $testApi = $this->module->apiClient->request('locations_for_shops',
            'GET', [
                'limit' => 1,
            ]);

        if ( ! $testApi->was_successful()) {
            $this->module->helper->redirectAfterReload(-1);
        }
		
		$countries = [];
		/* $countries[] = 'LT';
		$countries []= 'LV';
		$countries []= 'PL'; */
		$shipping_countries = Db::getInstance()->executeS("SELECT * FROM " . _DB_PREFIX_ . "country WHERE active = 1");
		
		foreach($shipping_countries as $shipping_country){
			$countries []= $shipping_country['iso_code'];
		}

        foreach ($carriers as $carrier) {
            $search   = [];
			//var_dump($carrier);
			 foreach ($countries as $country) {
				$search[] = 'courier_code:'.$carrier;
				$search[] = 'country_code:'.$country;

						$response = $this->module->apiClient->request('locations_for_shops',
						'GET', [
							'limit'  => 9999,
							'search' => implode(';', $search),
							'searchJoin' => 'and'
						]);

					if ($response->was_successful()) {
						Db::getInstance()
						  ->execute(sprintf("DELETE FROM %s WHERE `carrier_code` = '%s' and country_code ='%s' ",
							  _DB_PREFIX_.Multiparcelsshipping::TABLE_LOCATIONS,
							  $carrier, $country));

						$locations = $response->get_data();
						$count     += count($locations);

						foreach ($locations as $locationData) {
							$locationData = array_map(function ($value) {
								if (is_array($value)) {
									return array_map(function ($value) {
										return Db::getInstance()->escape($value);
									}, $value);
								}

								return Db::getInstance()->escape($value);
							}, $locationData);

							Db::getInstance()
							  ->insert(Multiparcelsshipping::TABLE_LOCATIONS, [
								  'carrier_code'  => $locationData['courier_code'],
								  'identifier'    => $locationData['identifier'],
								  'type'          => $locationData['type'],
								  'name'          => $locationData['name'],
								  'address'       => $locationData['address'],
								  'postal_code'   => $locationData['postal_code'],
								  'city'          => $locationData['city'],
								  'country_code'  => strtolower($locationData['country_code']),
								  'latitude'      => $locationData['latitude'],
								  'longitude'     => $locationData['longitude'],
								  'comment'       => $locationData['comment'],
								  'working_hours' => $locationData['working_hours'],
							  ]);
						}
					}
				}
			}
		
        return $count;
    }

    public function reload()
    {
        $this->updatePermissions();

        if ($this->module->configuration->getPermissions() == MultiParcels_Shipping_Permissions::CODE_NONE) {
            return -1;
        }

        $this->updateCarriers();
        $count = $this->updateLocations();
        $this->module->configuration->setLastUpdateAt(date('Y-m-d H:i:s'));
        $this->module->configuration->setLastVersionCheckAt(0); // force re-check

        return $count;
    }

    /**
     * @return array|false
     */
    public function checkLatestVersion()
    {
        // disable if no API key yet
        if(!$this->module->configuration->getApiKey()){
            return false;
        }

        $lastCheckAt = $this->module->configuration->getLastVersionCheckAt();

        $this->module->configuration->setLastVersionCheckAt(time());

        if ($lastCheckAt >= (60 * 60 * 24)) {
            return false;
        }

        $response = $this->module->apiClient->request('restricted_api/prestashop/latest_version');

        if ($response->was_successful()) {
            $data = $response->get_data();

            if (array_key_exists('version',
                    $data) && Multiparcelsshipping::VERSION != $data['version']) {
                // if there's a new version - always check
                $this->module->configuration->setLastVersionCheckAt(0);

                return $data;
            }
        }

        return false;
    }

}
