<?php

if ( ! defined('_PS_VERSION_')) {
    exit;
}

/**
 * Class MultiParcels_Shipping_Carriers
 */
class MultiParcels_Shipping_Carriers
{

    const TYPE_HANDS = 'hands';

    const TYPE_TERMINAL = 'terminal';

    /**
     * @var \Multiparcelsshipping
     */
    private $module;

    /** @var string[] $translations */
    private $translations;

    /**
     * MultiParcels_Shipping_Carriers constructor.
     *
     * @param  \Multiparcelsshipping  $module
     * @param  string[]  $translations
     */
    public function __construct(Multiparcelsshipping $module, $translations)
    {
        $this->module       = $module;
        $this->translations = $translations;
    }

    /**
     * @param  string  $code
     */
    public function enable($code)
    {
        $carrier = $this->get($code);
        if ( ! $this->get($code)) {
            return;
        }

        $this->module->configuration->enableCarrier($code);

        $types = [];

        if ($carrier['has_courier_service']) {
            $types[] = self::TYPE_HANDS;
        }

        if ($carrier['has_terminals'] || $carrier['has_pickup_points']) {
            $types[] = self::TYPE_TERMINAL;
        }

        foreach ($types as $type) {
            $this->addCarrierShipping($carrier, $type);
        }
    }

    protected function addCarrierShipping($carrier, $type)
    {
        $name = $carrier['name'];

        if ($type == self::TYPE_HANDS) {
            $name .= ' '.$this->translations['courier'];
        }

        if ($type == self::TYPE_TERMINAL) {
            $name .= ' '.$this->translations['terminals'];
        }

        $carrierEntity = new Carrier();

        $carrierEntity->name                 = $name;
        $carrierEntity->is_module            = true;
        $carrierEntity->active               = 1;
        $carrierEntity->range_behavior       = 1;
        $carrierEntity->need_range           = 1;
        $carrierEntity->shipping_external    = true;
        $carrierEntity->range_behavior       = 0;
        $carrierEntity->external_module_name = Multiparcelsshipping::NAME;
        $carrierEntity->shipping_method      = 2;

        foreach (Language::getLanguages() as $lang) {
            $carrierEntity->delay[$lang['id_lang']] = $name;
        }

        if ($carrierEntity->add() == true) {
            @copy(dirname(__FILE__).'/../views/img/carriers/'.$carrier['carrier_code'].'.png',
                _PS_SHIP_IMG_DIR_.'/'.(int)$carrierEntity->id.'.jpg');

            // Zone
            $id_zone_europe = Zone::getIdByName('Europe');
            $carrierEntity->addZone($id_zone_europe ? $id_zone_europe : 1);

            // Groups
            $groups_ids = [];
            $groups     = Group::getGroups(Context::getContext()->language->id);
            foreach ($groups as $group) {
                $groups_ids[] = $group['id_group'];
            }

            $carrierEntity->setGroups($groups_ids);

            // Ranges
            $range_price             = new RangePrice();
            $range_price->id_carrier = $carrierEntity->id;
            $range_price->delimiter1 = '0';
            $range_price->delimiter2 = '10000';
            $range_price->add();

            $range_weight             = new RangeWeight();
            $range_weight->id_carrier = $carrierEntity->id;
            $range_weight->delimiter1 = '0';
            $range_weight->delimiter2 = '10000';
            $range_weight->add();

            Db::getInstance()->insert(Multiparcelsshipping::TABLE_CARRIER, [
                'id_carrier'   => $carrierEntity->id,
                'carrier_code' => $carrier['carrier_code'],
                'type'         => $type,
            ]);

            return $carrierEntity;
        }

        return false;
    }

    /**
     * @param  string  $code
     */
    public function disable($code)
    {
        if ( ! $this->get($code)) {
            return;
        }

        /** @var PDOStatement $query */
        $query    = Db::getInstance()
                      ->query(sprintf("SELECT * FROM `%s` WHERE `carrier_code` = '%s'",
                          _DB_PREFIX_.Multiparcelsshipping::TABLE_CARRIER,
                          $code
                      ));
        $carriers = $query->fetchAll();

        foreach ($carriers as $carrier) {
            $where = "id_carrier = '".$carrier['id_carrier']."'";
            Db::getInstance()->update('carrier', [
                'deleted' => 1,
            ], $where);

            Db::getInstance()
              ->delete(Multiparcelsshipping::TABLE_CARRIER, $where);
        }

        $this->module->configuration->disableCarrier($code);
    }

    private function get($code)
    {
        $carriers = $this->module->configuration->getCarriers();

        if ( ! array_key_exists($code, $carriers['carriers'])) {
            return null;
        }

        return $carriers['carriers'][$code];
    }

}
