<?php

if ( ! defined('_PS_VERSION_')) {
    exit;
}

/**
 * Class MultiParcels_Shipping_Configuration
 */
class MultiParcels_Shipping_Configuration
{

    const PREFIX = 'MULTIPARCERLS_SHIPPING_';

    const KEY_API_KEY = 'API_KEY';

    const KEY_PERMISSIONS = 'PERMISSIONS';

    const KEY_LAST_UPDATE_AT = 'LAST_UPDATE_AT';

    const KEY_CARRIERS = 'CARRIERS';

    const KEY_CRON_TOKEN = 'CRON_TOKEN';

    const KEY_LAST_VERSION_CHECK_AT = 'LAST_VERSION_CHECK_AT';

    /**
     * @var \Multiparcelsshipping
     */
    private $module;

    /**
     * MultiParcels_Shipping_Configuration constructor.
     *
     * @param  \Multiparcelsshipping  $module
     */
    public function __construct(Multiparcelsshipping $module)
    {
        $this->module = $module;
    }

    public function get($key)
    {
        return Configuration::get(self::PREFIX.$key);
    }

    public function set($key, $value)
    {
        return Configuration::updateValue(self::PREFIX.$key, $value);
    }

    public function delete($key)
    {
        return Configuration::deleteByName(self::PREFIX.$key);
    }

    /**
     * @param  string  $value
     *
     * @return bool
     */
    public function setApiKey($value)
    {
        return $this->set(self::KEY_API_KEY, $value);
    }

    /**
     * @return false|string
     */
    public function getApiKey()
    {
        return $this->get(self::KEY_API_KEY);
    }

    /**
     * @param  string  $value
     *
     * @return bool
     */
    public function setPermissions($value)
    {
        return $this->set(self::KEY_PERMISSIONS, $value);
    }

    /**
     * @return false|string
     */
    public function getPermissions()
    {
        return $this->get(self::KEY_PERMISSIONS);
    }

    /**
     * @param  string  $value
     *
     * @return bool
     */
    public function setLastUpdateAt($value)
    {
        return $this->set(self::KEY_LAST_UPDATE_AT, $value);
    }

    /**
     * @return false|string
     */
    public function getLastUpdateAt()
    {
        return $this->get(self::KEY_LAST_UPDATE_AT);
    }

    /**
     * @param  array  $value
     *
     * @return bool
     */
    public function setCarriers($value)
    {
        return $this->set(self::KEY_CARRIERS, json_encode($value));
    }

    /**
     * @return array
     */
    public function getCarriers()
    {
        return json_decode($this->get(self::KEY_CARRIERS), true);
    }

    public function enableCarrier($code)
    {
        $this->set(self::KEY_CARRIERS.'_'.strtoupper($code), true);
    }

    public function disableCarrier($code)
    {
        $this->delete(self::KEY_CARRIERS.'_'.strtoupper($code));
    }

    public function checkCarrier($code)
    {
        return $this->get(self::KEY_CARRIERS.'_'.strtoupper($code));
    }

    /**
     * @param  string  $value
     *
     * @return bool
     */
    public function setCronToken($value)
    {
        return $this->set(self::KEY_CRON_TOKEN, $value);
    }

    /**
     * @return false|string
     */
    public function getCronToken()
    {
        $token = $this->get(self::KEY_CRON_TOKEN);

        if ( ! $token) {
            $token = mt_rand(1000000, 9999999);
            $this->setCronToken($token);
        }

        return $token;
    }

    /**
     * @param  string  $value
     *
     * @return bool
     */
    public function setLastVersionCheckAt($value)
    {
        return $this->set(self::KEY_LAST_VERSION_CHECK_AT, $value);
    }

    /**
     * @return false|string
     */
    public function getLastVersionCheckAt()
    {
        return $this->get(self::KEY_LAST_VERSION_CHECK_AT);
    }

}
