<?php

if ( ! defined('_PS_VERSION_')) {
    exit;
}

/**
 * Class MultiParcels_Shipping_Hooks
 */
class MultiParcels_Shipping_Hooks
{

    /**
     * @var \Multiparcelsshipping
     */
    private $module;

    /**
     * MultiParcels_Shipping_Hooks constructor.
     *
     * @param  \Multiparcelsshipping  $module
     */
    public function __construct(Multiparcelsshipping $module)
    {
        $this->module = $module;
    }

    /**
     * @param  array  $carrier
     *
     * @return false|string|null
     */
    public function displayPickupSelectionInCheckout($carrier)
    {
        if ( ! $carrier['carrier']['external_module_name'] == 'multiparcelsshipping') {
            return null;
        }
        $query = sprintf("SELECT * FROM `%s` WHERE `id_carrier` = '%d'",
            _DB_PREFIX_.Multiparcelsshipping::TABLE_CARRIER,
            $carrier['carrier']['id']);

        $settings = Db::getInstance()->getRow(
            $query
        );

        if ($settings == false || $settings['type'] != MultiParcels_Shipping_Carriers::TYPE_TERMINAL) {
            return null;
        }

        $delivery_address         = new Address((int)Context::getContext()->cart->id_address_delivery);
        $address_delivery_country = new Country($delivery_address->id_country);
        $deliveryCountryCode      = $address_delivery_country->iso_code;

        Context::getContext()->smarty->assign('module_dir',
            $this->module->getPathUri());
        Context::getContext()->smarty->assign('carrier_id',
            $carrier['carrier']['id']);
        Context::getContext()->smarty->assign('locationGroups',
            $this->module->locations->getForFrontend($settings['carrier_code'],
                $deliveryCountryCode));

        return Context::getContext()->smarty->fetch($this->module->getLocalPath().'views/templates/front/selection.tpl');
    }

    /**
     * @param  array  $params
     *
     * @return
     */
    public function checkIfPickupIsSelectedInCheckout(array $params, $text)
    {
        $request = $params['request_params'];
        if ($params['step_name'] != 'delivery') {
            return;
        }

        $cart    = $params['cart'];
        $carrier = new Carrier((int)$cart->id_carrier);
        if ($carrier->external_module_name != Multiparcelsshipping::NAME) {
            return;
        }

        // delete previous selection
        Db::getInstance()
          ->delete(Multiparcelsshipping::TABLE_CART,
              '`id_cart` = '.$params['cart']->id);

        if ( ! isset($request['multiparcels_terminal_'.$cart->id_carrier])) {
            return;
        }

        $selectedTerminal = $request['multiparcels_terminal_'.$cart->id_carrier];

        if ( ! $selectedTerminal) {
            Context::getContext()->controller->errors[] = $text;
            $params['completed']                        = false;

            return;
        }

        $carrierCode = Db::getInstance()
                         ->getValue(sprintf("SELECT `carrier_code` FROM `%s` WHERE `id_carrier` = '%d'",
                             _DB_PREFIX_.Multiparcelsshipping::TABLE_CARRIER,
                             (int)$cart->id_carrier));

        Db::getInstance()->insert(Multiparcelsshipping::TABLE_CART, [
            'id_cart'      => $params['cart']->id,
            'id_terminal'  => $selectedTerminal,
            'carrier_code' => $carrierCode,
        ]);
    }

    /**
     * @param  array  $params
     * @param  bool  $legacy displayAdminOrderTabContent update in 1.7.7
     * @return false|string
     * @throws SmartyException
     */
    public function adminOrderSelectedPickupLocation($params, $legacy = false)
    {
        if (!$legacy) {
            $search = $params['id_order'];
        } else {
            $search = $params['cart']->id;
        }

        $terminal = $this->module->locations->getByCartId($search);

        if ( ! $terminal) {
            return false;
        }

        Context::getContext()->smarty->assign('terminal', $terminal);

        return Context::getContext()->smarty->fetch($this->module->getLocalPath().'views/templates/admin/admin-order.tpl');
    }

    /**
     * @param  array  $params
     *
     * @return false|string
     */
    public function displaySelectedLocationInOrderConfirmation($params)
    {
        $terminal = $this->module->locations->getByCartId($params['order']->id_cart);

        if ( ! $terminal) {
            return false;
        }
        Context::getContext()->smarty->assign('terminal', $terminal);

        return Context::getContext()->smarty->fetch($this->module->getLocalPath().'views/templates/front/order-confirmation.tpl');
    }

    /**
     * @param $params
     *
     * @return false
     */
    public function displaySelectedLocationInOrderConfirmationEmail($params)
    {
        if ($params['template'] != 'order_conf') {
            return false;
        }

        $terminal = $this->module->locations->getByCartId($params['cart']->id);

        if ( ! $terminal) {
            return false;
        }

        if (isset($params['template_vars']['{delivery_block_html}'])) {
            // html delivery
            $deliveryInformation = $params['template_vars']['{delivery_block_html}'];
            $deliveryInformation .= sprintf("<br/>%s",
                $this->module->locations->title($terminal));

            $params['extra_template_vars']['{delivery_block_html}'] = $deliveryInformation;
        }

        if (isset($params['template_vars']['{delivery_block_txt}'])) {
            // text delivery
            $deliveryInformation = $params['template_vars']['{delivery_block_txt}'];
            $deliveryInformation .= sprintf("\n%s",
                $this->module->locations->title($terminal));

            $params['extra_template_vars']['{delivery_block_txt}'] = $deliveryInformation;
        }

        if (isset($params['template_vars']['{carrier}'])) {
            // carrier
            $carrier                                    = $params['template_vars']['{carrier}'];
            $params['extra_template_vars']['{carrier}'] = $carrier.sprintf(" (%s)",
                    $this->module->locations->title($terminal));
        }

        return false;
    }

    public function actionCarrierUpdate($params)
    {
        $old = (int)($params['id_carrier']);
        $new = (int)($params['carrier']->id);

        $query = sprintf("SELECT * FROM `%s` WHERE `id_carrier` = '%d'",
            _DB_PREFIX_.Multiparcelsshipping::TABLE_CARRIER,
            $old);

        $oldEntity = Db::getInstance()->getRow($query);
        if ( ! $oldEntity) {
            return;
        }

        Db::getInstance()->delete(Multiparcelsshipping::TABLE_CARRIER, "id_carrier = ".$old);

        Db::getInstance()->insert(Multiparcelsshipping::TABLE_CARRIER, [
            'id_carrier'   => $new,
            'carrier_code' => $oldEntity['carrier_code'],
            'type'         => $oldEntity['type'],
        ]);
    }

}
