<?php

if ( ! defined('_PS_VERSION_')) {
    exit;
}

/**
 * Class MultiParcels_Shipping_Locations
 */
class MultiParcels_Shipping_Locations
{


    /**
     * @var \Multiparcelsshipping
     */
    private $module;

    /**
     * MultiParcels_Shipping_Locations constructor.
     *
     * @param  \Multiparcelsshipping  $module
     */
    public function __construct(Multiparcelsshipping $module)
    {
        $this->module = $module;
    }

    public function all()
    {
        return Db::getInstance()
                 ->executeS(sprintf('SELECT * FROM '._DB_PREFIX_.'%s',
                     Multiparcelsshipping::TABLE_LOCATIONS));
    }

    /**
     * @param $carrierCode
     * @param $countryCode
     *
     * @return boolean
     */
    public function checkForFrontend($carrierCode, $countryCode)
    {
        $query = sprintf('SELECT count(*) FROM '._DB_PREFIX_."%s WHERE `country_code` = '%s' and `carrier_code` = '%s'",
            Multiparcelsshipping::TABLE_LOCATIONS,
            strtolower($countryCode),
            $carrierCode);

        return (int)Db::getInstance()->getValue($query) > 0;
    }

    public function getForFrontend($carrierCode, $countryCode)
    {
        $query = sprintf('SELECT * FROM '._DB_PREFIX_."%s WHERE `country_code` = '%s' and `carrier_code` = '%s'",
            Multiparcelsshipping::TABLE_LOCATIONS,
            strtolower($countryCode),
            $carrierCode);

        $items = Db::getInstance()
                   ->executeS($query);

        $groups    = [];

        if (count($items)) {
            foreach ($items as $item) {
                $location                                              = [
                    'identifier'    => $item['identifier'],
                    'first_line'    => $item['name'],
                    'second_line'   => sprintf("%s, %s, %s", $item['address'],
                        $item['city'],
                        $item['postal_code']),
                    'text'          => sprintf("%s, %s, %s, %s", $item['name'],
                        $item['address'],
                        $item['city'], $item['postal_code']),
                    'working_hours' => $item['working_hours'],
                    'comment'       => $item['comment'],
                ];
                $groups[$item['city']][$item['name'].$item['address']] = $location;
            }

            foreach ($groups as $key => $data) {
                ksort($groups[$key]);
            }

            ksort($groups);
            // For now only Lithuanian
            $priorityCities = [
                'Vilnius',
                'Kaunas',
                'Klaipėda',
            ];

            // needed for sorting properly
            $priorityCities = array_reverse($priorityCities);

            foreach ($priorityCities as $city) {
                if (array_key_exists($city, $groups)) {
                    $groups = [$city => $groups[$city]] + $groups;
                }
            }
        }

        return $groups;
    }

    public function title($location)
    {
        if ( ! $location) {
            return '';
        }

        return sprintf("%s, %s, %s, %s",
            $location['name'],
            $location['address'],
            $location['city'],
            $location['postal_code']);
    }

    public function get($identifier)
    {
        $query = sprintf(
            'SELECT * FROM '._DB_PREFIX_."%s WHERE `identifier` = '%s'",
            Multiparcelsshipping::TABLE_LOCATIONS,
            $identifier
        );

        return Db::getInstance()
                 ->getRow($query);
    }

    public function getByCartId($cartId)
    {
        $sql = sprintf('SELECT `id_terminal` FROM '._DB_PREFIX_.'%s WHERE id_cart=%d',
            Multiparcelsshipping::TABLE_CART, $cartId);

        if ($row = Db::getInstance()->getRow($sql)) {
            return $this->get($row['id_terminal']);
        }

        return null;
    }

    /**
     * @param $carrier
     *
     * @return object|array|bool|null
     */
    public function hasLocations($carrier)
    {
        $sql = sprintf('SELECT * FROM '._DB_PREFIX_."%s WHERE `carrier_code`= '%s'",
            Multiparcelsshipping::TABLE_LOCATIONS, $carrier);

        if ($row = Db::getInstance()->getRow($sql)) {
            return true;
        }

        return false;
    }

}
