{*
* 2007-2020 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2020 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*}

<div id="multiparcels_shipping_admin_logo">
    <img src="{$module_dir|escape:'html':'UTF-8'}/views/img/MultiParcels.svg"/>
</div>

{if $version_check}
    <div class="alert alert-success">
        <a href="{$configure_link}" class="close" data-dismiss="alert">×</a>

        {l s='New version %version% is available!' sprintf=['%version%' => $version_check.version] mod='multiparcelsshipping'}
        <br>

        <p>
            {$version_check.release_notes}
        </p>

        <a class="btn btn-default btn-primary" style="margin-top: 8px;" href="{$version_check.link}">
            {l s='Download now' mod='multiparcelsshipping'}
        </a>
    </div>
{/if}

{if $update_successful}
    {if $update_successful > 0}
        <div class="alert alert-success">
            <a href="{$configure_link}" class="close" data-dismiss="alert">×</a>

            {l s='Updated successfully. Pickup locations:' mod='multiparcelsshipping'} {$update_successful}
        </div>
    {else}
        <div class="alert alert-danger">
            <a href="{$configure_link}" class="close" data-dismiss="alert">×</a>

            {l s='Update failed.' mod='multiparcelsshipping'}
        </div>
    {/if}
{/if}

<form id="module_form" class="defaultForm form-horizontal" action="{$configure_link}" method="post"
      novalidate="">
    <input type="hidden" name="btnSubmit" value="1">

    <div class="panel" id="fieldset_0">

        <div class="panel-heading">
            <i class="icon-truck"></i> MultiParcels
        </div>

        <div class="form-wrapper">
            <div class="form-group">
                <label class="control-label col-lg-3">
                    {l s='API key' mod='multiparcelsshipping'}
                </label>
                <div class="col-lg-9">
                    <input type="text" name="api_key" value="{$api_key}" class=""
                           style="max-width: 150px;">
                </div>
            </div>
        </div>

        <div class="form-wrapper">
            <div class="form-group">
                <label class="control-label col-lg-3">
                    {l s='Permissions' mod='multiparcelsshipping'}
                </label>
                <div class="col-lg-9" style="line-height: 34px;">
                    {if $permissions == 'none'}
                        {$permissions_text}
                        <br>
                        {l s='E-mail' mod='multiparcelsshipping'}:
                        <br>
                        <input type="email" name="multiparcels_free_api_email" value="{$admin_email}">
                        <button type="submit" class="btn btn-primary pointer"
                                name="submitMultiparcelsshippingModuleFreeApi">
                            {l s='Get a free API key' mod='multiparcelsshipping'}
                        </button>
                        <br>
                        <small>
                            *{l s='By continuing you agree to occasionally receive information about new features, important notices about security etc. to your e-mail address' mod='multiparcelsshipping'}
                            {l s='You can unsubscribe any time!' mod='multiparcelsshipping'}
                        </small>
                    {else}
                        {$permissions_text}
                    {/if}
                </div>
            </div>
        </div>
        {if isset($carriers.carriers)}
            <div class="form-wrapper">
                <div class="form-group">
                    <label class="control-label col-lg-3">
                        {l s='Carriers' mod='multiparcelsshipping'}
                    </label>
                    <div class="col-lg-9">	
                        {foreach from=$carriers.carriers item=carrier key="key"}
							{if $carrier.carrier_code != 'dpd'}
								<div class="form-group">
									<label class="col-sm-2 control-label" for="input-status"></label>
									<div class="col-sm-10" style="margin-top: 10px;">

										<div class="clearfix">
											<div style="width: 150px;text-align: center;float: left;">
												<img src="../modules/multiparcelsshipping/views/img/carriers/{$carrier.carrier_code}.png"
													 style="width: 100%;"><br>
												{$carrier.name}
											</div>

											{if !$carrier.enabled}
												<div style="width: 150px;float: left;padding-top: 15px;padding-left: 15px;">
													<a href="{$carrier.enable_link}" class="btn btn-default btn-primary">
														{l s='Enable' mod='multiparcelsshipping'}
													</a>
												</div>
											{else}
												<div style="width: 150px;float: left;padding-top: 15px;padding-left: 15px;">
													<a href="{$carriers_link}" class="btn btn-default">
														{l s='Settings' mod='multiparcelsshipping'}
													</a>

													{if !$carrier.has_locations}
														<br>
														<div style="color: red;margin-top: 5px;">
															{l s='No locations found. Please try to run manual update' mod='multiparcelsshipping'}
														</div>
														<br>
														<a class="btn btn-danger" id="page-header-desc-configuration-add_module" href="{$reload_link}">
															{l s='Manual update' mod='multiparcelsshipping'}
														</a><br>
													{/if}
												</div>
												<div style="width: 150px;float: left;padding-top: 15px;padding-left: 15px;">
													<a href="{$carrier.disable_link}" class="btn btn-default">
														{l s='Disable' mod='multiparcelsshipping'}
													</a>
												</div>
											{/if}
										</div>
									</div>
								</div>
							{/if}
                        {/foreach}
                    </div>
                </div>
            </div>
        {/if}

        <div class="form-wrapper">
            <div class="form-group">
                <label class="control-label col-lg-3">
                    {l s='Data update' mod='multiparcelsshipping'}
                </label>
                <div class="col-lg-9">
                    <a class="btn btn-primary" id="page-header-desc-configuration-add_module" href="{$reload_link}">
                        {l s='Manual update' mod='multiparcelsshipping'}
                    </a><br>
                    {l s='Last update' mod='multiparcelsshipping'}:
                    <strong>
                        {if $last_update_at}
                            {$last_update_at}
                        {else}
                            {l s='Never' mod='multiparcelsshipping'}
                        {/if}
                    </strong><br><br>

                    {l s='Setup automatic updates with cron' mod='multiparcelsshipping'}: <br>
                    <input type="text" value="{$cron_url}" onClick="this.select();" readonly><br>
                    {l s='Recommended to run at night, example 6:00' mod='multiparcelsshipping'}
                </div>
            </div>
        </div>

        <div class="form-wrapper">
            <div class="form-group">
                <label class="control-label col-lg-3">
                    {l s='Pickup locations' mod='multiparcelsshipping'}
                </label>
                <div class="col-lg-9">

                    {if !$show_locations}
                        <a class="btn btn-primary" href="{$show_locations_link}">
                            {l s='Show' mod='multiparcelsshipping'}
                        </a>
                    {else}
							<div class="locations-list">
								<div class="locations-list-item header">
									<div>{l s='Carrier' mod='multiparcelsshipping'}</div>
									<div>{l s='Identification' mod='multiparcelsshipping'}</div>
									<div>{l s='Type' mod='multiparcelsshipping'}</div>
									<div>{l s='Name' mod='multiparcelsshipping'}</div>
									<div>{l s='Address' mod='multiparcelsshipping'}</div>
									<div>{l s='Postal code' mod='multiparcelsshipping'}</div>
									<div>{l s='City' mod='multiparcelsshipping'}</div>
									<div>{l s='Country' mod='multiparcelsshipping'}</div>
								</div>

								{foreach from=$locations item=location}
									{if $location.carrier_code != 'dpd'}
									<div class="locations-list-item">
										<div>{$location.carrier_code}</div>
										<div>{$location.identifier}</div>
										<div>{$location.type}</div>
										<div>{$location.name}</div>
										<div>{$location.address}</div>
										<div>{$location.postal_code}</div>
										<div>{$location.city}</div>
										<div>{$location.country_code}</div>
									</div>
									{/if}
								{/foreach}
							</div>
							<style>
								.locations-list {
									display: flex;
									width: 100%;
									flex-direction: column;
								}

								.locations-list > div {
									flex: 1;
								}

								.locations-list-item {
									width: 100%;
									display: flex;
								}

								.locations-list-item > div {
									flex: 1;
									padding: 3px;
									border: 1px solid #ccc;
								}

								.locations-list-item.header {
									font-weight: bold;
								}
							</style>
                    {/if}
                </div>
            </div>
        </div>

        <div class="panel-footer">
            <button type="submit" value="1" id="module_form_submit_btn" name="submitMultiparcelsshippingModule"
                    class="btn btn-default pull-right">
                <i class="process-icon-save"></i> {l s='Save' mod='multiparcelsshipping'}
            </button>
        </div>

    </div>
</form>
